# vim: set sw=4 ts=4 et nu:
#
# spec file for package mruby
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
%define sover 3_1_0
Name:           mruby
Version:        3.1.0
Release:        1.9
Summary:        Lightweight Ruby
License:        MIT
Group:          Development/Languages/Ruby
URL:            https://github.com/mruby/mruby/
Source:         %{url}/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE PATCH-FEATURE-UPSTREAM link-with-soname.patch -- Add SONAME to library
Patch0:         link-with-soname.patch
# PATCH-FIX-UPSTREAM CVE-2022-1286.patch -- boo#1198289 https://github.com/mruby/mruby/commit/b1d0296a
Patch2:         CVE-2022-1286.patch
# PATCH-FIX-UPSTREAM CVE-2022-1212.patch -- https://github.com/mruby/mruby/commit/3cf291f72224715942beaf8553e42ba8891ab3c6
Patch3:         CVE-2022-1212.patch
BuildRequires:  bison
BuildRequires:  cmake
BuildRequires:  pkgconfig
%if 0%{?suse_version} >= 1500
BuildRequires:  %{rb_default_ruby_suffix}
%else
BuildRequires:  rubygem(%{rb_default_ruby_abi}:rake)
%endif

%description
mruby is the lightweight implementation of the Ruby language complying to (part
of) the ISO standard.

mruby can be linked and embedded within your application.

We provide the interpreter program "mruby" and the interactive mruby shell
"mirb" as examples.

You can also compile Ruby programs into compiled byte code using the mruby
compiler "mrbc".

The "mrbc" is also able to generate compiled byte code in a C source file.

%package devel
Summary:        Lightweight Ruby Embedded Environment
Group:          Development/Languages/Ruby
Requires:       libmruby%{sover} = %{version}
Requires:       libmruby_core%{sover} = %{version}

%description devel
mruby is the lightweight implementation of the Ruby language complying to (part
of) the ISO standard.

This package contains the headers and static library files in order to embed
mruby into your application.

%package -n libmruby%{sover}
Summary:        Lightweight Ruby Embedded Environment
Group:          Development/Languages/Ruby
# Was wrongly used (only) on Factory until 02-2022
Obsoletes:      libmruby3 < %{version}

%description -n libmruby%{sover}
mruby is the lightweight implementation of the Ruby language complying to (part
of) the ISO standard.

%package -n libmruby_core%{sover}
Summary:        Lightweight Ruby Embedded Environment
Group:          Development/Languages/Ruby

%description -n libmruby_core%{sover}
mruby is the lightweight implementation of the Ruby language complying to (part
of) the ISO standard.

%prep
%autosetup -p1
# Currently broken
sed -i 's|conf.enable_debug|# conf.enable_debug|' build_config/host-shared.rb

%build
export CFLAGS="%{optflags}"
export LDFLAGS="%{optflags}"
export MRUBY_CONFIG="host-shared"
# Needed for mruby to find its libraries before they are installed
export LD_LIBRARY_PATH="$PWD/build/host/mrbc/lib/"
rake all

%install
# Install binaries
for b in mirb mrbc mruby; do
    install -D -m 0755 "bin/${b}" "%{buildroot}%{_bindir}/${b}"
done

# Install libraries
for l in mruby mruby_core; do
	l=l"ib$l.so"
    install -D -m 0755 "build/host/lib/${l}.%{version}" "%{buildroot}%{_libdir}/$l.%{version}"
    ln -s "${l}.%{version}" "%{buildroot}%{_libdir}/${l}"
done

install -d "%{buildroot}%{_includedir}"
cp -a include/* "%{buildroot}%{_includedir}/"

%post   -p /sbin/ldconfig -n libmruby%{sover}
%post   -p /sbin/ldconfig -n libmruby_core%{sover}
%postun -p /sbin/ldconfig -n libmruby%{sover}
%postun -p /sbin/ldconfig -n libmruby_core%{sover}

%files -n libmruby%{sover}
%{_libdir}/libmruby.so.%{version}

%files -n libmruby_core%{sover}
%{_libdir}/libmruby_core.so.%{version}

%files
%doc AUTHORS CONTRIBUTING.md LEGAL NEWS README.md
%license LICENSE
%{_bindir}/mirb
%{_bindir}/mrbc
%{_bindir}/mruby
%{_bindir}/mrbc

%files devel
%{_includedir}/mr*.h
%{_includedir}/mruby
%{_libdir}/libmruby*.so

%changelog
* Wed Feb 15 2023 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 3.1.0
  * New features:
  * CRuby3.0 compatible keyword arguments are introduced.
  * Keyword arguments are basically separated from ordinal arguments.
  * Implement endless-def
  * Replace `R-assignment` by `single-line pattern matching`
  * Support squiggly heredocs.
  * Hash value omission
  * New library methods
  * New supported directives for `mrbgems/mruby-pack`
  * Breaking Changes
  * `Kernel#printf` (`mruby-sprintf`) Format specifiers `%%a` and `%%A` are removed.
  * `Kernel#puts` (`mruby-print`) Now expand Array arguments.
  * mruby binaries are no longer backward compatible.
  * Upgrade mruby VM version `RITE_VM_VER` to `0300` (means mruby 3.0 or after).
  * Upgrade mruby binary version `RITE_BINARY_FORMAT_VER` to `0300`.
  * `mruby3.0` removed `OP_EXT1`, `OP_EXT2`, `OP_EXT3` for operand extension.
    But the operand size limitations was too tight for real-world application.
    `mruby3.1` reintroduces those extension instructions.
  * Some instructions are removed and some new are added,
    see full changelog https://github.com/mruby/mruby/blob/3.1.0/doc/mruby3.1.md
  * Fixed CVEs:
    CVE-2021-4110, CVE-2021-4188, CVE-2022-0080, CVE-2022-0240,
    CVE-2022-0326, CVE-2022-0481, CVE-2022-0631, CVE-2022-0632,
    CVE-2022-0890, CVE-2022-1071, CVE-2022-1106, CVE-2022-1201,
    CVE-2022-1427
- Drop upstream fixed:
  * CVE-2021-4110.patch
  * CVE-2022-0240.patch
  * CVE-2022-0080.patch
  * CVE-2022-0481.patch
- Replaced b1d0296a.patch with CVE-2022-1286.patch
* Tue Apr 26 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Add b1d0296a.patch: fixing CVE-2022-1286 / boo#1198289
- Add CVE-2022-1212.patch: fixing CVE-2022-1212 / boo#1198089
* Mon Feb 21 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Install libmruby_core library, required by mruby binary
- Fix missing SONAME in library by adding link-with-soname.patch
* Wed Feb  9 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Added CVE-2022-0481.patch from upstream
  fixed NULL Pointer Dereference boo#1195632 / CVE-2022-0481
- Fixed file attributes (executable bit for shared library)
* Tue Jan 18 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Added CVE-2022-0080.patch from upstream,
  fixed Heap-based Buffer Overflow boo#1194244 / CVE-2022-0080
* Tue Jan 18 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Added CVE-2022-0240.patch from upstream,
  fixed NULL Pointer Dereference boo#1194808 / CVE-2022-0240
* Thu Dec 16 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Added CVE-2021-4110.patch from upstream, fixes boo#1193796 / CVE-2021-4110
* Sat May 15 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.0.0
  * New Core Language Features
  * Implement endless-def. Ruby:Feature#16746
  * Replace R-assignment by single-line pattern matching.
    Ruby:Feature#15921
  * Support squiggly heredocs. Ruby:Feature#5246
  * Breaking Changes
  * mruby VM and bytecode:
    mruby binaries are no longer backward compatible
    Upgrade mruby VM version RITE_VM_VER to 0300 (means mruby 3.0).
    Upgrade mruby binary version RITE_BINARY_FORMAT_VER to 0200.
  * Integer has been changed to a specification similar to CRuby.
  * Integrate Fixnum and Integer.
  * Remove Integral.
  * int / int -> int
  * Add APIs for Integer.
  * Full change log:
    https://mruby.org/releases/2021/03/05/mruby-3.0.0-released.html
* Fri May  7 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.1.2
  * IO#readchar returns a UTF-8 character fragment instead of
    EOFError if EOF is reached in the middle of UTF-8 characters.
  * This behavior is different from CRuby, but it is a mruby
    specification that supports either ASCII or UTF-8 exclusively.
  * Remove mrb_run() from C APIs.
  * Fixed segmentation fault at mrb_io_s_select
  * Fixed segmentation fault at mrb_vm_exec.
  * Fixed some Hash methods are inconsistent with values when hash
    has duplicate key.
  * Fixed get local variable names from orphan block.
  * Fixed memory leaks in some places when out of memory.
  * Fixed heap buffer overflow in mruby interpreter.
  * Fixed type tag not used when calculating hash code.
  * Full log:
    https://mruby.org/releases/2020/08/06/mruby-2.1.2-released.html
* Mon Jun 15 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 2.1.1
  too many changes to include here
  https://mruby.org/releases/2020/06/04/mruby-2.1.1-released.html
  https://mruby.org/releases/2019/11/19/mruby-2.1.0-released.html
  https://mruby.org/releases/2019/04/04/mruby-2.0.1-released.html
  https://mruby.org/releases/2018/12/11/mruby-2.0.0-released.html
  https://mruby.org/releases/2018/04/27/mruby-1.4.1-released.html
  https://mruby.org/releases/2017/07/04/mruby-1.3.0-released.html
  https://mruby.org/releases/2015/11/18/mruby-1.2.0-released.html
  https://mruby.org/releases/2014/11/19/mruby-1.1.0-released.html
  https://mruby.org/releases/2014/02/09/mruby-1.0.0-released.html
* Tue Jul  3 2012 pascal.bleser@opensuse.org
- initial version (0.0+20120701)
